@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2012-2016 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2012-2019 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -71,7 +71,9 @@ struct _AsComponentClass
  * @AS_COMPONENT_KIND_FIRMWARE:		Firmware
  * @AS_COMPONENT_KIND_DRIVER:		A driver
  * @AS_COMPONENT_KIND_LOCALIZATION:	Software localization (usually l10n resources)
+ * @AS_COMPONENT_KIND_SERVICE:		A system service launched by the init system
  * @AS_COMPONENT_KIND_REPOSITORY:	A remote software or data source
+ * @AS_COMPONENT_KIND_OPERATING_SYSTEM: A computer operating system
  *
  * The type of an #AsComponent.
  **/
@@ -90,6 +92,7 @@ typedef enum  {
 	AS_COMPONENT_KIND_LOCALIZATION,
 	AS_COMPONENT_KIND_SERVICE,
 	AS_COMPONENT_KIND_REPOSITORY,
+	AS_COMPONENT_KIND_OPERATING_SYSTEM,
 	/*< private >*/
 	AS_COMPONENT_KIND_LAST
 } AsComponentKind;
@@ -104,6 +107,7 @@ AsComponentKind		as_component_kind_from_string (const gchar *kind_str);
  * @AS_MERGE_KIND_NONE:		No merge is happening.
  * @AS_MERGE_KIND_REPLACE:	Merge replacing data of target.
  * @AS_MERGE_KIND_APPEND:	Merge appending data to target.
+ * @AS_MERGE_KIND_REMOVE_COMPONENT: Remove the entire component if it matches.
  *
  * Defines how #AsComponent data should be merged if the component is
  * set for merge.
@@ -112,6 +116,7 @@ typedef enum  {
 	AS_MERGE_KIND_NONE,
 	AS_MERGE_KIND_REPLACE,
 	AS_MERGE_KIND_APPEND,
+	AS_MERGE_KIND_REMOVE_COMPONENT,
 	/*< private >*/
 	AS_MERGE_KIND_LAST
 } AsMergeKind;
